@@ -3,10 +3,9 @@ package UUID::Generator::PurePerl::Compat;
 use strict;
 use warnings;
 
-our $VERSION = '0.02_01';
+our $VERSION = '0.01';
 
-use Exporter;
-*import = \&Exporter::import;
+use Exporter 'import';
 
 our @EXPORT = qw( NameSpace_DNS NameSpace_URL NameSpace_OID NameSpace_X500 );
 
@@ -172,73 +171,11 @@ UUID::Generator::PurePerl::Compat - Compatible interface to Data::UUID
 
 =head1 DESCRIPTION
 
-This class provides compatibility layer to L<Data::UUID>.
-
-If you want to know functionality of each method,
-Please refer to L<Data::UUID>.
-
-=head1 METHODS
-
-Following methods and constants are implemented:
-
-=over 2
-
-=item $ug = CLASS->new()
-
-=item $ug->create()
-
-=item $ug->create_bin()
-
-=item $ug->create_hex()
-
-=item $ug->create_b64()
-
-=item $ug->create_from_name(<namespace>, <name>)
-
-=item $ug->create_from_name_bin(<namespace>, <name>)
-
-=item $ug->create_from_name_hex(<namespace>, <name>)
-
-=item $ug->create_from_name_b64(<namespace>, <name>)
-
-=item $ug->to_string(<uuid>)
-
-=item $ug->to_hexstring(<uuid>)
-
-=item $ug->to_b64string(<uuid>)
-
-=item $ug->from_string(<uuid_str>)
-
-=item $ug->from_hexstring(<uuid_str>)
-
-=item $ug->from_b64string(<uuid_str>)
-
-=item $ug->compare(<uuid1>, <uuid2>)
-
-=item NameSpace_DNS()
-
-=item NameSpace_URL()
-
-=item NameSpace_OID()
-
-=item NameSpace_X500()
-
-=back
-
-=head1 NOTICE
-
-As written in L<UUID::Object/"NOTICE ABOUT PORTABILITY">,
-binary and Base64 form of UUIDs generated by L<Data::UUID>
-depend on endian of platform.
-
-This module inherits that behavior of L<Data::UUID>,
-so UUIDs generated with those methods,
-such like C<create_bin()> and C<create_from_name_b64()>,
-may not be compatible over machines.
+This class provides compatibility layer to Data::UUID.
 
 =head1 SEE ALSO
 
-L<Data::UUID>, L<UUID::Generator::PurePerl>.
+L<UUID::Generator::PurePerl>, L<Data::UUID>.
 
 =head1 AUTHOR
 
