@@ -3,8 +3,7 @@ package UUID::Generator::PurePerl::Util;
 use strict;
 use warnings;
 
-use Exporter;
-*import = \&Exporter::import;
+use Exporter 'import';
 
 our @EXPORT = qw( digest_as_octets digest_as_32bit digest_as_16bit );
 
@@ -57,7 +56,7 @@ __END__
 
 =head1 NAME
 
-UUID::Generator::PurePerl::Util - Utility functions for UUID::Generator::PurePerl
+UUID::Generator::PurePerl::Util - Utitily functions for UUID::Generator::PurePerl
 
 =head1 DESCRIPTION
 
